@@ -23,7 +23,7 @@ class Multineurone:
     def lineal_error(self, pred):
         self.error = self.out - pred
 
-    def grlearn(self):
+    def grlearn(self, inputs):
         self.wb -= self.rate * self.error * self.b
         for i in range(self.ninputs):
             self.weights[i] -= self.rate * self.error * inputs[i]
@@ -38,7 +38,7 @@ class Multineurone:
             if self.error == 0:
                 break
             else:
-                self.grlearn()
+                self.grlearn(inputs)
         return errors
 
     def use(self, inputs):
